@@ -20,11 +20,17 @@ class ClassicGridworld(NoisyGridworld):
     **termination**: Earning a nonzero reward.
     """
 
+    layout = """
+|   G|
+| X G|
+|S   |
+"""
+
     def __init__(self):
-        super().__init__(dims=(4, 3), starts={(0, 0)}, blocks=frozenset({(1, 1)}))
+        super().__init__(ClassicGridworld.layout)
 
     def _reward(self, state, action, next_state):
         return {(3, 1): -1.0, (3, 2): 1.0}.get(state, 0.0)
 
     def _done(self, state, action, next_state):
-        return state in {(3, 1), (3, 2)}
+        return state in self._goals
